# Table of Contents

- [configuring-sso-with-microsoft-entra-id](<./configuring-sso-with-microsoft-entra-id.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SSO with Microsoft Entra ID](<./Configuring-SSO-with-Microsoft-Entra-ID.md>)
  - [Prerequisites](<./Configuring-SSO-with-Microsoft-Entra-ID/Prerequisites.md>)
  - [Step 1: Create an SSO Application and Configure SAML Settings](<./Configuring-SSO-with-Microsoft-Entra-ID/Step-1-Create-an-SSO-Application-and-Configure-SAML-Settings.md>)
  - [Step 2: Configure SAML Token Attributes](<./Configuring-SSO-with-Microsoft-Entra-ID/Step-2-Configure-SAML-Token-Attributes.md>)
  - [Configuring Role Attributes](<./Configuring-SSO-with-Microsoft-Entra-ID/Configuring-Role-Attributes.md>)
